Poly1d
======

.. currentmodule:: numpy

Basics
------
.. autosummary::
   :toctree: generated/

   poly1d
   polyval
   poly
   roots

Fitting
-------
.. autosummary::
   :toctree: generated/

   polyfit

Calculus
--------
.. autosummary::
   :toctree: generated/

   polyder
   polyint

Arithmetic
----------
.. autosummary::
   :toctree: generated/

   polyadd
   polydiv
   polymul
   polysub

Warnings
--------
.. autosummary::
   :toctree: generated/

   RankWarning
